==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Spanish</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Sistema Libre de notificación para nuevos correos de Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Integrado con Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Seleccionar cómo integrar el programa en Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Ejecución automática</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Empezar automáticamente ${PRODUCT_NAME} después del arranque.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Autocomprobación de actualizaciones</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Buscar automáticamente actualizaciones de ${PRODUCT_NAME} al empezar.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Entrada en el Grupo del programa</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Crear un Grupo de programa de ${PRODUCT_NAME} en el Menú de Inicio &gt; Programas.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Entrada en el Escritorio</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Crear un icono de ${PRODUCT_NAME} en el Escritorio.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Entrada en el Menú de Inicio</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Crear un icono de ${PRODUCT_NAME} en el Menú de Inicio.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Seleccione idioma para ${PRODUCT_NAME}. ${PRODUCT_NAME} elegirá el idioma basandose en el idioma del sistema.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} Preferencias del usuario</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Tus preferencias y configuraciones hechas con ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Iniciar ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Pulsa en desinstalar para empezar el proceso.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Desinstalando la versión previa de ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>¡La desistalación de la versión antigua de ${PRODUCT_NAME} ha fallado! Continuar borrara TODO en $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Error en la ejecución del desinstalador.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} está actualmente en ejecución. Presione OK para parar ${PRODUCT_NAME} y continuar con la instalación.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Cerrando proceso ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Fallo cerrando ${PRODUCT_NAME}. Por favor, reintentelo o trate de cerrar manualmente ${PRODUCT_NAME} para continuar con la instalación.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} está actualmente en ejecución. Presione OK para parar ${PRODUCT_NAME} y continuar con la desinstalación.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Fallo cerrando ${PRODUCT_NAME}. Por favor, reintentelo o trate de cerrar manualmente ${PRODUCT_NAME} para continuar con la desinstalación.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>La configuracíon de ${PRODUCT_NAME} está en ejecución.$\r$\nPor favor, cierre todas las instancias y pulse Reintentar para continuar, o Cancelar para salir.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>La desinstalación de ${PRODUCT_NAME} está en ejecución.$\r$\nPor favor, cierre todas las instancias y pulse Reintentar para continuar, o Cancelar para salir.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>El direccitorio de instalación no debe contener$\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>El directorio de instalación contiene una versión previa instalada de ${PRODUCT_NAME}, que será reemplazada.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>El directorio de instalación no está vacio, pero no parece que contenga una versión previa de ${PRODUCT_NAME}. El contenido será sobreescrito.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (solo el usuario actual)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} No pudo instalarse completamente.$\r$\nPor favor, reinicie Windows y vuelva a ejecutar el programa de instalación de nuevo.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} No pudo instalarse completamente.$\r$\nPor favor, reinicie Windows y vuelva a ejecutar el programa de instalación de nuevo.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} No pudo desinstalarse completamente.$\r$\nPor favor, reinicie Windows y vuelva a ejecutar el programa de desinstalación de nuevo.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Error eleminando el fichero:$\r$\n$\r$\n$0$\r$\n$\r$\nPulse Reintentar para volver a probar, o$\r$\nCancelar para parar la desinstalación.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Error durante la eliminación del fichero $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Estás instalando una versión de 32 bit de ${PRODUCT_NAME} en un Windows a 64 bit. Hay una versión de 64 bit ${PRODUCT_NAME} disponible para descargar.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>El programa de instalación contiene una versión de 64 bit de ${PRODUCT_NAME}. Tu ordenador está ejecutando una versión de 32 bit de Windows, la cual no puede ejecutar programas 64 bit. Por favor, descarge la versión de 32 bit de ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>El programa requiere al menos Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>La desinstalación de ${PRODUCT_NAME} ha sido abortada. Por favor, inténtelo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} configuración</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>El desinstalador se ha iniciado con privilegios de administador pero parece ser no ser una instalación de ${PRODUCT_NAME} de administrador. ¿Quiere volver a ejecutar el desinstalador sin privilegios de administrador?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Abriendo $0 en su navegador por defecto...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>No se ha podido encontrar Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>No se ha podido encontrar el siguiente componente requerido en su sistema:$\r$\nVisual C++ Runtime ${ARCH}$\r$\n¿Quiere descargar el instalador de este componente?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Una vez completadas las descargas, por favor ejecute el instalador descargado. Cuando el instalador haya finalizado, pulse OK para comprobar el estado de la instalación de nuevo.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>El componente requerido ha sido detectado satisfactoriamente en su ordenador.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>El componente requerido no ha sido encontrado en su ordenador. Por favor, busque online descargas de Visual C++ ${ARCH} para Visual Studio 2015 y superior.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} no podrá ser ejecutado.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} no podra iniciarse poruqe un componente requerido no está presente.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Neerlandés</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Español</translation>
    </message>
</context>
</TS>

==> birdtray_1.9.0+ds.orig.tar.xz: birdtray-1.9.0/src/translations/installer_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Spanish</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Sistema Libre de notificación para nuevos correos de Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Integrado con Windows</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Seleccionar cómo integrar el programa en Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Ejecución automática</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Empezar automáticamente ${PRODUCT_NAME} después del arranque.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Autocomprobación de actualizaciones</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Buscar automáticamente actualizaciones de ${PRODUCT_NAME} al empezar.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Entrada en el Grupo del programa</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Crear un Grupo de programa de ${PRODUCT_NAME} en el Menú de Inicio &gt; Programas.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Entrada en el Escritorio</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Crear un icono de ${PRODUCT_NAME} en el Escritorio.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Entrada en el Menú de Inicio</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Crear un icono de ${PRODUCT_NAME} en el Menú de Inicio.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Seleccione idioma para ${PRODUCT_NAME}. ${PRODUCT_NAME} elegirá el idioma basandose en el idioma del sistema.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME} Preferencias del usuario</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Tus preferencias y configuraciones hechas con ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>Iniciar ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Pulsa en desinstalar para empezar el proceso.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Desinstalando la versión previa de ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>¡La desistalación de la versión antigua de ${PRODUCT_NAME} ha fallado! Continuar borrara TODO en $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>Error en la ejecución del desinstalador.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} está actualmente en ejecución. Presione OK para parar ${PRODUCT_NAME} y continuar con la instalación.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Cerrando proceso ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Fallo cerrando ${PRODUCT_NAME}. Por favor, reintentelo o trate de cerrar manualmente ${PRODUCT_NAME} para continuar con la instalación.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} está actualmente en ejecución. Presione OK para parar ${PRODUCT_NAME} y continuar con la desinstalación.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Fallo cerrando ${PRODUCT_NAME}. Por favor, reintentelo o trate de cerrar manualmente ${PRODUCT_NAME} para continuar con la desinstalación.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>La configuracíon de ${PRODUCT_NAME} está en ejecución.$\r$\nPor favor, cierre todas las instancias y pulse Reintentar para continuar, o Cancelar para salir.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>La desinstalación de ${PRODUCT_NAME} está en ejecución.$\r$\nPor favor, cierre todas las instancias y pulse Reintentar para continuar, o Cancelar para salir.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>El direccitorio de instalación no debe contener$\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>El directorio de instalación contiene una versión previa instalada de ${PRODUCT_NAME}, que será reemplazada.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>El directorio de instalación no está vacio, pero no parece que contenga una versión previa de ${PRODUCT_NAME}. El contenido será sobreescrito.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (solo el usuario actual)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} No pudo instalarse completamente.$\r$\nPor favor, reinicie Windows y vuelva a ejecutar el programa de instalación de nuevo.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} No pudo instalarse completamente.$\r$\nPor favor, reinicie Windows y vuelva a ejecutar el programa de instalación de nuevo.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} No pudo desinstalarse completamente.$\r$\nPor favor, reinicie Windows y vuelva a ejecutar el programa de desinstalación de nuevo.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Error eleminando el fichero:$\r$\n$\r$\n$0$\r$\n$\r$\nPulse Reintentar para volver a probar, o$\r$\nCancelar para parar la desinstalación.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Error durante la eliminación del fichero $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>Estás instalando una versión de 32 bit de ${PRODUCT_NAME} en un Windows a 64 bit. Hay una versión de 64 bit ${PRODUCT_NAME} disponible para descargar.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>El programa de instalación contiene una versión de 64 bit de ${PRODUCT_NAME}. Tu ordenador está ejecutando una versión de 32 bit de Windows, la cual no puede ejecutar programas 64 bit. Por favor, descarge la versión de 32 bit de ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>El programa requiere al menos Windows ${MIN_WINDOWS_VER}.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>La desinstalación de ${PRODUCT_NAME} ha sido abortada. Por favor, inténtelo de nuevo más tarde.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME} configuración</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>El desinstalador se ha iniciado con privilegios de administador pero parece ser no ser una instalación de ${PRODUCT_NAME} de administrador. ¿Quiere volver a ejecutar el desinstalador sin privilegios de administrador?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Abriendo $0 en su navegador por defecto...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>No se ha podido encontrar Visual C++ Runtime ${ARCH}.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>No se ha podido encontrar el siguiente componente requerido en su sistema:$\r$\nVisual C++ Runtime ${ARCH}$\r$\n¿Quiere descargar el instalador de este componente?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Una vez completadas las descargas, por favor ejecute el instalador descargado. Cuando el instalador haya finalizado, pulse OK para comprobar el estado de la instalación de nuevo.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>El componente requerido ha sido detectado satisfactoriamente en su ordenador.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>El componente requerido no ha sido encontrado en su ordenador. Por favor, busque online descargas de Visual C++ ${ARCH} para Visual Studio 2015 y superior.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} no podrá ser ejecutado.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} no podra iniciarse poruqe un componente requerido no está presente.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Inglés</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Neerlandés</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Español</translation>
    </message>
    <message>
        <source>Lang_sv</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <source>Lang_tr</source>
        <translation>Turco</translation>
    </message>
    <message>
        <source>Lang_pl</source>
        <translation>Polaco</translation>
    </message>
</context>
</TS>
